@@ -40,7 +40,6 @@ import urlparse
 import warnings
 
 from restkit.util import url_quote
-from restkit.util.misc import deprecated_property
 
 from couchdbkit.exceptions import *
 import couchdbkit.resource as resource
@@ -97,9 +96,6 @@ class Server(object):
                                 filters=filters)
         self._uuids = []
         
-    def close(self):
-        self.res.close()
-        
     def info(self):
         """ info of server
 
@@ -119,24 +115,30 @@ class Server(object):
         """
         return self.res.get('/_all_dbs').json_body
 
-    def create_db(self, dbname):
+    def create_db(self, dbname, **params):
         """ Create a database on CouchDb host
 
         @param dname: str, name of db
+        @param param: custom parameters to pass to create a db. For
+        example if you use couchdbkit to access to cloudant or bigcouch:
+            
+            Ex: q=12 or n=4
+
+        See https://github.com/cloudant/bigcouch for more info.
 
         @return: Database instance if it's ok or dict message
         """
         return Database(self._db_uri(dbname), create=True,
-                    server=self)
+                    server=self, **params)
 
-    def get_or_create_db(self, dbname):
+    def get_or_create_db(self, dbname, **params):
         """
         Try to return a Database object for dbname. If
         database doest't exist, it will be created.
 
         """
         return Database(self._db_uri(dbname), create=True,
-                    server=self)
+                    server=self, **params)
 
     def delete_db(self, dbname):
         """
@@ -225,7 +227,7 @@ class Database(object):
     """
 
     def __init__(self, uri, create=False, server=None, pool_instance=None,
-            filters=None):
+            filters=None, **params):
         """Constructor for Database
 
         @param uri: str, Database uri
@@ -252,7 +254,7 @@ class Database(object):
             try:
                 self.server.res.head('/%s/' % self.dbname)
             except ResourceNotFound:
-                self.server.res.put('/%s/' % self.dbname).json_body
+                self.server.res.put('/%s/' % self.dbname, **params).json_body
 
 
         self.res = server.res(self.dbname)
@@ -260,9 +262,6 @@ class Database(object):
     def __repr__(self):
         return "<%s %s>" % (self.__class__.__name__, self.dbname)
 
-    def close(self):
-        self.res.close()
-
     def info(self):
         """
         Get database information
@@ -390,7 +389,7 @@ class Database(object):
         @return rev: str, the last revision of document.
         """
         response = self.res.head(resource.escape_docid(docid))
-        return response.headers['etag'].strip('"')
+        return response['etag'].strip('"')
 
     def save_doc(self, doc, encode_attachments=True, force_update=False,
             **params):
@@ -512,7 +511,8 @@ class Database(object):
                         '_rev': res['rev']
                     })
         if errors:
-            raise BulkSaveError(errors)
+            raise BulkSaveError(errors, results)
+        return results
     bulk_save = save_docs
 
     def delete_docs(self, docs, all_or_nothing=False):
