@@ -26,7 +26,7 @@ import urllib
 import urlparse
 
 from couchdbkit import Server, contain, ResourceConflict
-from couchdbkit.loaders import FileSystemDocLoader
+from couchdbkit import push
 from couchdbkit.resource import CouchdbResource, PreconditionFailed
 from django.conf import settings
 from django.db.models import signals, get_app
@@ -39,13 +39,13 @@ COUCHDB_TIMEOUT = getattr(settings, "COUCHDB_TIMEOUT", 300)
 
 class CouchdbkitHandler(object):
     """ The couchdbkit handler for django """
-    
+
     # share state between instances
     __shared_state__ = dict(
-        _databases = {},
-        app_schema = SortedDict()
+            _databases = {},
+            app_schema = SortedDict()
     )    
-       
+
     def __init__(self, databases):
         """ initialize couchdbkit handler with COUCHDB_DATABASES
         settings """
@@ -54,7 +54,7 @@ class CouchdbkitHandler(object):
 
         # create databases sessions
         for app_name, uri in databases:
-            
+
             try:
                 if isinstance(uri, tuple):
                     # case when you want to specify server uri 
@@ -65,35 +65,47 @@ class CouchdbkitHandler(object):
                     server_uri, dbname = uri.rsplit("/", 1)
             except ValueError:
                 raise ValueError("couchdb uri [%s:%s] invalid" % (
-                            app_name, uri))
+                    app_name, uri))
+
                 
             res = CouchdbResource(server_uri, timeout=COUCHDB_TIMEOUT)
-            
+
             server = Server(server_uri, resource_instance=res)
             app_label = app_name.split('.')[-1]
-            self._databases[app_label] = server.get_or_create_db(dbname)
+            self._databases[app_label] = (server, dbname)
     
     def sync(self, app, verbosity=2):
         """ used to sync views of all applications and eventually create
-        database """
+        database.
+        """
         app_name = app.__name__.rsplit('.', 1)[0]
         app_label = app_name.split('.')[-1]
         if app_label in self._databases:
             if verbosity >=1:
                 print "sync `%s` in CouchDB" % app_name
-            db = self._databases[app_label]
-            try:
-                db.server.create_db(db.dbname)
-            except:
-                pass
-                
+            db = self.get_db(app_label)
+
             app_path = os.path.abspath(os.path.join(sys.modules[app.__name__].__file__, ".."))
-            loader = FileSystemDocLoader(app_path, "_design", design_name=app_label)
-            loader.sync(db)
+            design_path = "%s/%s" % (app_path, "_design")
+            if not os.path.isdir(design_path):
+                if settings.DEBUG:
+                    print >>sys.stderr, "%s don't exists, no ddoc synchronized" % design_path
+                return
+
+            push(os.path.join(app_path, "_design"), db, force=True,
+                    docid="_design/%s" % app_label)
                 
-    def get_db(self, app_label):
+    def get_db(self, app_label, register=False):
         """ retrieve db session for a django application """
-        return self._databases[app_label]
+        if register:
+            return
+
+        db = self._databases[app_label]
+        if isinstance(db, tuple):
+            server, dbname = db
+            db = server.get_or_create_db(dbname)
+            self._databases[app_label] = db
+        return db
                 
     def register_schema(self, app_label, *schema):
         """ register a Document object"""
@@ -106,7 +118,6 @@ class CouchdbkitHandler(object):
                 if os.path.splitext(fname1)[0] == os.path.splitext(fname2)[0]:
                     continue
             schema_dict[schema_name] = s
-            s._db = self.get_db(app_label)
 
     def get_schema(self, app_label, schema_name):
         """ retriev Document object from its name and app name """
